@@ -3,11 +3,7 @@
  *
  * Copyright (C) 2005-2010  NTT DATA CORPORATION
  *
- * Version: 1.8.0-pre   2010/10/25
- *
- * This file is applicable to both 2.4.30 and 2.6.11 and later.
- * See README.ccs for ChangeLog.
- *
+ * Version: 1.8.0+   2010/12/31
  */
 
 #include <linux/version.h>
@@ -111,8 +107,8 @@ static _Bool ccs_policy_loader_exists(void)
 		return 1;
 	}
 #endif
-	printk(KERN_INFO "Not activating Mandatory Access Control now "
-	       "since %s doesn't exist.\n", ccs_loader);
+	printk(KERN_INFO "Not activating Mandatory Access Control "
+	       "as %s does not exist.\n", ccs_loader);
 	return 0;
 }
 
@@ -272,7 +268,10 @@ const struct ccsecurity_exports ccsecurity_exports = {
 	.find_task_by_pid_ns = find_task_by_pid_ns,
 #endif
 };
+#ifdef CONFIG_CCSECURITY_LKM
+/* Only ccsecurity module need to access this struct. */
 EXPORT_SYMBOL_GPL(ccsecurity_exports);
+#endif
 
 /* Members are updated by loadable kernel module. */
 struct ccsecurity_operations ccsecurity_ops = {
@@ -281,5 +280,9 @@ struct ccsecurity_operations ccsecurity_ops = {
 	.disabled = 1,
 #endif
 };
-EXPORT_SYMBOL_GPL(ccsecurity_ops);
+/*
+ * Non-GPL modules might need to access this struct via inlined functions
+ * embedded into include/linux/security.h and include/net/ip.h
+ */
+EXPORT_SYMBOL(ccsecurity_ops);
 #endif
