@@ -1,9 +1,9 @@
 /*
  * security/ccsecurity/memory.c
  *
- * Copyright (C) 2005-2010  NTT DATA CORPORATION
+ * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 1.8.0   2010/11/11
+ * Version: 1.8.0+   2011/01/21
  */
 
 #include "internal.h"
@@ -43,25 +43,27 @@ unsigned int ccs_memory_quota[CCS_MAX_MEMORY_STAT];
 /**
  * ccs_memory_ok - Check memory quota.
  *
- * @ptr:  Pointer to allocated memory.
- * @size: Size in byte.
+ * @ptr:  Pointer to allocated memory. Maybe NULL.
+ * @size: Size in byte. Not used if @ptr is NULL.
  *
  * Returns true if @ptr is not NULL and quota not exceeded, false otherwise.
  */
 bool ccs_memory_ok(const void *ptr, const unsigned int size)
 {
-	size_t s = ccs_round2(size);
-	bool result;
-	spin_lock(&ccs_policy_memory_lock);
-	ccs_memory_used[CCS_MEMORY_POLICY] += s;
-	result = ptr && (!ccs_memory_quota[CCS_MEMORY_POLICY] ||
-			 ccs_memory_used[CCS_MEMORY_POLICY] <=
-			 ccs_memory_quota[CCS_MEMORY_POLICY]);
-	if (!result)
-		ccs_memory_used[CCS_MEMORY_POLICY] -= s;
-	spin_unlock(&ccs_policy_memory_lock);
-	if (result)
-		return true;
+	if (ptr) {
+		const size_t s = ccs_round2(size);
+		bool result;
+		spin_lock(&ccs_policy_memory_lock);
+		ccs_memory_used[CCS_MEMORY_POLICY] += s;
+		result = !ccs_memory_quota[CCS_MEMORY_POLICY] ||
+			ccs_memory_used[CCS_MEMORY_POLICY] <=
+			ccs_memory_quota[CCS_MEMORY_POLICY];
+		if (!result)
+			ccs_memory_used[CCS_MEMORY_POLICY] -= s;
+		spin_unlock(&ccs_policy_memory_lock);
+		if (result)
+			return true;
+	}
 	ccs_warn_oom(__func__);
 	return false;
 }
@@ -244,7 +246,12 @@ out:
 #ifdef CONFIG_CCSECURITY_USE_EXTERNAL_TASK_SECURITY
 
 /* Dummy security context for avoiding NULL pointer dereference. */
-static struct ccs_security ccs_null_security = {
+static struct ccs_security ccs_oom_security = {
+	.ccs_domain_info = &ccs_kernel_domain
+};
+
+/* Dummy security context for avoiding NULL pointer dereference. */
+static struct ccs_security ccs_default_security = {
 	.ccs_domain_info = &ccs_kernel_domain
 };
 
@@ -298,8 +305,8 @@ static int __ccs_alloc_task_security(const struct task_struct *task)
  *
  * @task: Pointer to "struct task_struct".
  *
- * Returns pointer to "struct ccs_security" on success, &ccs_null_security
- * otherwise.
+ * Returns pointer to "struct ccs_security" on success, &ccs_oom_security on
+ * out of memory, &ccs_default_security otherwise.
  *
  * If @task is current thread and "struct ccs_security" for current thread was
  * not found, I try to allocate it. But if allocation failed, current thread
@@ -322,16 +329,16 @@ struct ccs_security *ccs_find_task_security(const struct task_struct *task)
 	}
 	rcu_read_unlock();
 	if (task != current)
-		return &ccs_null_security;
+		return &ccs_default_security;
 	/* Use GFP_ATOMIC because caller may have called rcu_read_lock(). */
 	ptr = kzalloc(sizeof(*ptr), GFP_ATOMIC);
 	if (!ptr) {
 		printk(KERN_WARNING "Unable to allocate memory for pid=%u\n",
 		       task->pid);
 		send_sig(SIGKILL, current, 0);
-		return &ccs_null_security;
+		return &ccs_oom_security;
 	}
-	*ptr = ccs_null_security;
+	*ptr = ccs_default_security;
 	ptr->task = task;
 	ccs_add_task_security(ptr, list);
 	return ptr;
@@ -381,7 +388,7 @@ static void __ccs_free_task_security(const struct task_struct *task)
 {
 	unsigned long flags;
 	struct ccs_security *ptr = ccs_find_task_security(task);
-	if (ptr == &ccs_null_security)
+	if (ptr == &ccs_default_security || ptr == &ccs_oom_security)
 		return;
 	spin_lock_irqsave(&ccs_task_security_list_lock, flags);
 	list_del_rcu(&ptr->list);
